# Vue-DPlayer

> A Vue 2.x video player component based on [DPlayer](https://github.com/DIYgod/DPlayer).

[Live Demo](https://sinchang.github.io/vue-dplayer/)

## Install

```bash
npm install vue-dplayer -S
```

## Usage

```js
import VueDPlayer from 'vue-dplayer'

export default {
  components: {
    'd-player': VueDPlayer
  }
}
```
## Props

| Name | Type | Default | Description |
| ---- | ---- | ------- | ----------- |
| autoplay | Boolean | false | autoplay video, not supported by mobile browsers |
| theme | String | #FADFA3 | theme color |
| loop | Boolean | true | loop play music |
| screenshot | Boolean | false | enable screenshot function |
| hotkey | Boolean | true | binding hot key, including left right and Space |
| preload | String | 'auto' | the way to load video, can be 'none' 'metadata' or 'auto' |
| video| Object | `required` | video.url -> video link is required, video.pic -> video poster |

## Events

| Name | Params | Description |
| ---- | ------ | ----------- |
| play | none | Triggered when DPlayer start play |
| pause | none | Triggered when DPlayer paused |
| canplay | none | Triggered when enough data is available that DPlayer can play |
| playing | none | Triggered periodically when DPlayer is playing |
| ended | none | Triggered when DPlayer ended playing |
| error | none | Triggered when an error occurs |

Example:

```js
<d-player  @play="play"></d-player>

export default {
    methods: {
      play() {
        console.log('play callback')
      }
    }
```

## API

you can use all DPlayer [APIs](http://dplayer.js.org/docs/#/?id=api)

Example:

```js
<d-player ref="player"></d-player>

export default {
    mounted() {
      const player = this.$refs.player.dp
      player.play()
      setTimeout(() => {
        player.pause()
      }, 2000)
    }
```
## Related

- [vue-aplayer](https://github.com/SevenOutman/vue-aplayer)
- [DPlayer](https://github.com/DIYgod/DPlayer)

## Development

- `yarn example`: Run example in development mode
- `yarn deploy`: Deploy example to gh-pages
- `yarn build:cjs`: Build component in commonjs format
- `yarn build:umd`: Build component in umd format
- `yarn build`: Build component in both format
- `yarn lint`: Run eslint

Check out your npm scripts, it's using [vbuild](https://github.com/egoist/vbuild) under the hood.

---

Generated by [create-vue-app](https://github.com/egoist/create-vue-app)

# License

This content is released under the [MIT](http://opensource.org/licenses/MIT) License.
